=======
Credits
=======

Development Lead
----------------

* ZNC Sistemas <contato@znc.com.br>

Contributors
------------

* * Luiz Fernando Barbosa Vital ( @luizvital )
* Carlos E. C. Leite ( @cadu-leite )
* Joilson Marques ( @joilsonmarques )
* george-silva
* Marcelo Fonseca Tambalo ( @zokis )
* Douglas Soares de Andrade ( @douglas )
* Fabio C. Barrionuevo da Luz ( @luzfcb ) <bnafta at gmail dot com>
